pub struct QueryCacheConfig {
pub capacity: NonZeroUsize,
pub default_ttl: Duration,
pub min_ttl: Duration,
pub max_ttl: Duration,
}Expand description
Configuration for QueryCache.
Fields
capacity: NonZeroUsizeMaximum number of entries the cache will hold.
When capacity is reached, the least-recently-used entry is evicted first, unless there are stale (TTL-expired) entries which are evicted before LRU.
default_ttl: DurationDefault TTL for entries that do not specify their own TTL.
min_ttl: DurationMinimum allowed TTL (lower bound for per-entry TTL).
max_ttl: DurationMaximum allowed TTL (upper bound for per-entry TTL).