pub struct CommunityGraph {
pub nodes: HashMap<u64, GraphNode>,
pub edges: Vec<GraphEdge>,
pub adjacency: HashMap<u64, Vec<(u64, f64)>>,
}Expand description
Undirected weighted graph with adjacency lists
Fields
nodes: HashMap<u64, GraphNode>Node collection indexed by ID
edges: Vec<GraphEdge>All edges (stored once; adjacency is bidirectional)
adjacency: HashMap<u64, Vec<(u64, f64)>>Adjacency list: node_id → [(neighbour_id, weight)]
Implementations
Sourceimpl CommunityGraph
impl CommunityGraph
Sourcepub fn add_node(&mut self, id: u64, label: &str)
pub fn add_node(&mut self, id: u64, label: &str)
Add a node; overwrites if the ID already exists
Sourcepub fn add_edge(&mut self, from: u64, to: u64, weight: f64)
pub fn add_edge(&mut self, from: u64, to: u64, weight: f64)
Add an undirected edge between from and to with the given weight.
If either node does not exist it is created with an empty label.
Sourcepub fn degree(&self, node_id: u64) -> f64
pub fn degree(&self, node_id: u64) -> f64
Sum of edge weights incident to a node (weighted degree)
Sourcepub fn total_weight(&self) -> f64
pub fn total_weight(&self) -> f64
Sum of all edge weights in the graph (counted once per edge)