pub struct DistributedEntityResolver<E: EndpointExecutor> { /* private fields */ }Expand description
Resolves entity identity across endpoints using owl:sameAs links.
The resolver computes the transitive sameAs closure: if A sameAs B and B sameAs C, all three are placed in the same equivalence class.
Implementations
Sourceimpl<E: EndpointExecutor + 'static> DistributedEntityResolver<E>
impl<E: EndpointExecutor + 'static> DistributedEntityResolver<E>
Sourcepub fn new(config: FederatedGraphRAGConfig, executor: Arc<E>) -> Self
pub fn new(config: FederatedGraphRAGConfig, executor: Arc<E>) -> Self
Create a new resolver
Sourcepub async fn same_as_closure(
&self,
uris: &[String],
) -> GraphRAGResult<HashMap<String, String>>
pub async fn same_as_closure( &self, uris: &[String], ) -> GraphRAGResult<HashMap<String, String>>
Compute the transitive owl:sameAs closure for the given URIs across all active endpoints.
Returns a map from each input URI (and discovered aliases) to the canonical representative URI for its equivalence class.
Sourcepub fn apply_to_graph(
&self,
kg: &mut KnowledgeGraph,
canonical_map: &HashMap<String, String>,
)
pub fn apply_to_graph( &self, kg: &mut KnowledgeGraph, canonical_map: &HashMap<String, String>, )
Apply sameAs closure to a knowledge graph, rewriting URIs to canonical forms and deduplicating triples that become identical after rewriting.