pub struct EntityLinker {
pub nil_threshold: f64,
/* private fields */
}Expand description
Links entity mentions in text to knowledge-base entities.
Fields
nil_threshold: f64Minimum confidence threshold below which an entity is treated as NIL.
Implementations
Sourceimpl EntityLinker
impl EntityLinker
Sourcepub fn add_entity(
&mut self,
iri: impl Into<String>,
label: impl Into<String>,
aliases: &[&str],
)
pub fn add_entity( &mut self, iri: impl Into<String>, label: impl Into<String>, aliases: &[&str], )
Add an entity to the knowledge base.
context is an optional textual description used for TF-IDF
disambiguation.
Sourcepub fn build_index(&mut self)
pub fn build_index(&mut self)
Finalise the TF-IDF index (call after all entities are added).
Sourcepub fn link(&self, text: &str) -> Vec<LinkedEntity>
pub fn link(&self, text: &str) -> Vec<LinkedEntity>
Find and link all entity mentions in text.
Sourcepub fn candidate_generation(&self, mention: &str) -> Vec<EntityCandidate>
pub fn candidate_generation(&self, mention: &str) -> Vec<EntityCandidate>
Generate entity candidates matching the mention by string similarity.
Sourcepub fn disambiguate(
&self,
_mention: &EntityMention,
candidates: &[EntityCandidate],
context: &str,
) -> Option<EntityCandidate>
pub fn disambiguate( &self, _mention: &EntityMention, candidates: &[EntityCandidate], context: &str, ) -> Option<EntityCandidate>
Disambiguate among candidates using context TF-IDF similarity.
Sourcepub fn entity_count(&self) -> usize
pub fn entity_count(&self) -> usize
Number of entities in the knowledge base.