pub struct StreamingSubgraphExtractor { /* private fields */ }Expand description
In-memory streaming subgraph manager.
Implementations
Sourceimpl StreamingSubgraphExtractor
impl StreamingSubgraphExtractor
Sourcepub fn new(max_depth: usize, max_nodes: usize) -> Self
pub fn new(max_depth: usize, max_nodes: usize) -> Self
Create a new extractor.
max_depth– BFS depth limit for subgraph extractionmax_nodes– node cap for subgraph extraction
Sourcepub fn add_triple(&mut self, s: &str, p: &str, o: &str) -> Vec<SubgraphEvent>
pub fn add_triple(&mut self, s: &str, p: &str, o: &str) -> Vec<SubgraphEvent>
Add a triple to the graph and emit the corresponding events.
Returns the events produced by this mutation (also buffered internally).
Sourcepub fn remove_triple(&mut self, s: &str, p: &str, o: &str) -> Vec<SubgraphEvent>
pub fn remove_triple(&mut self, s: &str, p: &str, o: &str) -> Vec<SubgraphEvent>
Remove a triple from the graph and emit the corresponding events.
Returns the events produced by this mutation.
Sourcepub fn extract_subgraph(
&self,
pattern: &SubgraphPattern,
) -> Vec<(String, String, String)>
pub fn extract_subgraph( &self, pattern: &SubgraphPattern, ) -> Vec<(String, String, String)>
Extract (subject, predicate, object) triples matching pattern.
If pattern.anchor is "?x" the extractor uses all known subjects
as starting points (up to max_nodes).
Sourcepub fn extract_neighborhood(
&self,
node: &str,
depth: usize,
) -> Vec<(String, String, String)>
pub fn extract_neighborhood( &self, node: &str, depth: usize, ) -> Vec<(String, String, String)>
Extract the BFS neighbourhood of node up to depth hops.
Sourcepub fn drain_events(&mut self) -> Vec<SubgraphEvent>
pub fn drain_events(&mut self) -> Vec<SubgraphEvent>
Drain and return all buffered events.
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Number of nodes currently in the graph.
Sourcepub fn edge_count(&self) -> usize
pub fn edge_count(&self) -> usize
Number of directed edges currently in the graph.